blogs.Entry (Blog Entry) — amici1

# `blogs.Entry` (Blog Entry)

A blog entry is a short article with a title, published on a given

  date and time by a given user.

Master tables : blogs.AllEntries (Blog Entries), blogs.Entries (Blog Entries), blogs.LatestEntries (Latest blog entries), blogs.MyEntries (My Blog Entries)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Controlled by (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Controlled by (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Body (body) : An editable text body.

- Preview (body_short_preview) : A read-only preview of the first paragraph of body.

- Preview (full) (body_full_preview) : A read-only full preview of body.

- Heading (title) : See `<django.db.models.fields.CharField: title>`.

- Publication date (pub_date) : See `<django.db.models.fields.DateField: pub_date>`.

- Publication time (pub_time) : See `<lino.core.fields.TimeField: pub_time>`.

- Blog Entry Type (entry_type) : See `<django.db.models.fields.related.ForeignKey: entry_type>`.

- Language (language) : See `<lino.utils.mldbc.fields.LanguageField: language>`.

- Add interest (add_interest) : See `lino_xl.lib.blogs.models.Entry.add_interest`.

- Name (name_column) : See `lino_xl.lib.blogs.models.Entry.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.blogs.models.Entry.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.blogs.models.Entry.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
owner_type | Controlled by (type) |
owner_id | Controlled by (object) |
body | Body | An editable text body.
body_short_preview | Preview | A read-only preview of the first paragraph of body.
body_full_preview | Preview (full) | A read-only full preview of body.
title | Heading |
pub_date | Publication date |
pub_time | Publication time |
entry_type | Blog Entry Type |
language | Language |
owner | Controlled by |
add_interest | Add interest |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |